main
library
Functions
-
embedNativeServerLibrary(List<int> bytes)
→ void
-
Gives this process the native server library as bytes. Nothing to load
where there is no FFI, so this only records that the call was made.
-
serve(Future<Response> handler(Request), {String host = '127.0.0.1', int port = 8080, TlsConfig? tls, bool h2c = false, CorsOptions? cors, String? staticDir, String? spaRoot, bool compression = true, Duration requestTimeout = const Duration(seconds: 60), int maxBodyBytes = 1024 * 1024, Iterable<DVRouteBodyLimit> routeBodyLimits = const <DVRouteBodyLimit>[]})
→ Future<ServerHandle>
-
Serves the handler configuration.