NativeWebSocketChannel class

Inheritance
Implemented types
  • StreamChannelMixin

Constructors

NativeWebSocketChannel(int id, DartvelShelfBindings _api, String? protocol, int maxMessageSize, Duration? pingInterval)

Properties

closeCode ↔ int?
The close code set when the WebSocket connection is closed.
getter/setter pair
closeReason ↔ String?
The close reason set when the WebSocket connection is closed.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id → int
final
maxMessageSize → int
final
protocol → String?
The subprotocol selected by the server.
final
ready → Future<void>
A future that will complete when the WebSocket connection has been established.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sink → WebSocketSink
The sink for sending values to the other endpoint.
no setteroverride
stream → Stream<Object?>
The single-subscription stream that emits values from the other endpoint.
no setteroverride

Methods

cast<S>() → StreamChannel<S>
Returns a copy of this with the generic type coerced to S.
inherited
changeSink(StreamSink<Object?> change(StreamSink<Object?>)) → StreamChannel<Object?>
Returns a copy of this with sink replaced by change's return value.
inherited
changeStream(Stream<Object?> change(Stream<Object?>)) → StreamChannel<Object?>
Returns a copy of this with stream replaced by change's return value.
inherited
dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onWakeup() → void
pipe(StreamChannel<Object?> other) → void
Connects this to other, so that any values emitted by either are sent directly to the other.
inherited
send(Object? message) → Future<void>
Waits for native queue capacity. Await each send or use sink.addStream.
start(Duration? interval) → void
toString() → String
A string representation of this object.
inherited
transform<S>(StreamChannelTransformer<S, Object?> transformer) → StreamChannel<S>
Transforms this using transformer.
inherited
transformSink(StreamSinkTransformer<Object?, Object?> transformer) → StreamChannel<Object?>
Transforms only the sink component of this using transformer.
inherited
transformStream(StreamTransformer<Object?, Object?> transformer) → StreamChannel<Object?>
Transforms only the stream component of this using transformer.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited